Keccak sha3_256 hashing for PyPy2 and Python 2 using a C library through cffi bindings

Please note that this package uses the "old" Keccak standard and not FIPS202. 

Install
-------

```
python setup.py install
```
